package com.jjt.biz.controller;

import com.jjt.biz.domain.*;
import com.jjt.biz.service.IBluetoothInfoService;
import com.jjt.biz.service.IDeviceInfoService;
import com.jjt.biz.service.IVenueInfoService;
import com.jjt.biz.service.IWifiInfoService;
import com.jjt.common.annotation.Log;
import com.jjt.common.core.controller.BaseController;
import com.jjt.common.core.domain.AjaxResult;
import com.jjt.common.core.page.TableDataInfo;
import com.jjt.common.enums.BusinessType;
import com.jjt.common.utils.poi.ExcelUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 蓝牙信息Controller
 *
 * @author ruoyi
 * @date 2023-07-06
 */
@RestController
@RequestMapping("/index")
public class IndexController extends BaseController {
    @Resource
    private IBluetoothInfoService bluetoothInfoService;
    @Resource
    private IDeviceInfoService deviceInfoService;
    @Resource
    private IWifiInfoService wifiInfoService;
    @Resource
    private IVenueInfoService venueInfoService;

    /**
     * 首页信息
     */
    @GetMapping("/info")
    public Map<String, Object> info() {
        Map<String, Object> map = new HashMap<>(16);
        List deviceInfos = deviceInfoService.selectDeviceInfoList(new DeviceInfo());
        map.put("deviceNO", deviceInfos.size());
        List<WifiInfo> wifiInfos = wifiInfoService.selectWifiInfoList(new WifiInfo());
        List wifis = wifiInfos.stream()
                .filter(bean -> bean.getIsIllegal().equals("Y"))
                .collect(Collectors.toList());
        map.put("totalWifiNO", wifiInfos.size());
        map.put("wifiNO", wifis.size());
        List<BluetoothInfo> bluetoothInfos = bluetoothInfoService.selectBluetoothInfoList(new BluetoothInfo());
        List blues = bluetoothInfos.stream()
                .filter(bean -> bean.getIsIllegal().equals("Y"))
                .collect(Collectors.toList());
        map.put("totalBluetoothNO", bluetoothInfos.size());
        map.put("bluetoothNO", blues.size());
        List venueInfos = venueInfoService.selectVenueInfoList(new VenueInfo());
        map.put("venueNO", venueInfos.size());
        return map;
    }

    /**
     * 首页信息
     */
    @GetMapping("/top")
    public List<TopVO> top() {
        List<TopVO> list = venueInfoService.selectTop10();
        if (list.size() == 0 || (list.size() > 0 && list.get(0).getBluetooth() == 0 && list.get(0).getWifi() == 0)) {
            list = new ArrayList<>();
            list.add(new TopVO("东安湖体育公园游泳跳水馆", 87, 84));
            list.add(new TopVO("东安湖体育公园多功能体育馆", 33, 80));
            list.add(new TopVO("凤凰山体育公园", 99, 89));
            list.add(new TopVO("高新体育中心体育馆", 75, 74));
            list.add(new TopVO("简阳文体中心游泳馆", 65, 78));
            list.add(new TopVO("简阳文体中心体育馆", 2, 23));
            list.add(new TopVO("四川大学望江校区体育馆", 78, 41));
            list.add(new TopVO("电子科技大学清水河校区体育馆", 49, 41));
            list.add(new TopVO("西南财大光华校区体育馆", 25, 60));
            list.add(new TopVO("西南交通大学犀浦校区体育馆", 32, 83));
        }
        return list;
    }
}
